This is an automated email from the ASF dual-hosted git repository.

rpuch pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/ignite-3.git


The following commit(s) were added to refs/heads/main by this push:
     new d3f54cd331 IGNITE-23026 Improve configuration structure (#4248)
d3f54cd331 is described below

commit d3f54cd3311e3d858788fe04ca21ee1c89d490ab
Author: Roman Puchkovskiy <[email protected]>
AuthorDate: Wed Aug 21 17:01:59 2024 +0400

    IGNITE-23026 Improve configuration structure (#4248)
---
 .../config/cluster-config.adoc                     |  6 ++---
 .../administrators-guide/config/node-config.adoc   | 30 ++++------------------
 .../config/storage/persistent.adoc                 |  6 ++---
 .../config/storage/table-configuration.adoc        |  4 +--
 .../config/storage/volatile.adoc                   |  3 +--
 docs/_docs/developers-guide/data-streamer.adoc     |  2 +-
 docs/_docs/general-tips.adoc                       |  4 +--
 .../apache/ignite/table/DataStreamerOptions.java   | 28 ++++++++++----------
 .../internal/client/table/ClientDataStreamer.java  |  4 +--
 .../org/apache/ignite/client/DataStreamerTest.java |  4 +--
 .../ignite/client/PartitionAwarenessTest.java      |  2 +-
 .../ignite/internal/streamer/StreamerOptions.java  |  6 ++---
 .../internal/streamer/StreamerSubscriber.java      |  2 +-
 .../ignite/internal/util/FastTimestamps.java       |  4 +--
 .../internal/streamer/StreamerSubscriberTest.java  | 10 ++++----
 .../internal/lowwatermark/LowWatermarkImpl.java    |  4 +--
 .../lowwatermark/LowWatermarkImplTest.java         |  4 +--
 .../PageMemoryCheckpointConfigurationSchema.java   | 11 +++++---
 ...latilePageMemoryProfileConfigurationSchema.java |  4 ---
 .../persistence/checkpoint/Checkpointer.java       | 16 ++++++------
 .../persistence/checkpoint/CheckpointerTest.java   | 18 ++++++-------
 .../Apache.Ignite.Tests/Table/DataStreamerTests.cs |  8 +++---
 .../Apache.Ignite/Internal/Table/DataStreamer.cs   | 10 ++++----
 .../Internal/Table/DataStreamerWithReceiver.cs     |  4 +--
 .../Apache.Ignite/Table/DataStreamerOptions.cs     |  6 ++---
 .../configuration/RaftConfigurationSchema.java     |  4 +--
 .../VolatileRaftConfigurationSchema.java           |  2 +-
 .../apache/ignite/internal/raft/ItLozaTest.java    |  2 +-
 .../java/org/apache/ignite/internal/raft/Loza.java |  2 +-
 .../ignite/internal/replicator/ReplicaManager.java |  2 +-
 .../inmemory/ItRaftStorageVolatilityTest.java      |  2 +-
 .../streamer/ItAbstractDataStreamerTest.java       |  4 +--
 .../LowWatermarkConfigurationSchema.java           |  4 +--
 .../internal/sql/sqllogic/ItSqlLogicTest.java      |  2 +-
 .../raftsnapshot/ItTableRaftSnapshotsTest.java     |  4 +--
 .../threading/ItTablesApiThreadingTest.java        |  9 ++++---
 .../apache/ignite/internal/table/DataStreamer.java |  4 +--
 37 files changed, 111 insertions(+), 130 deletions(-)

diff --git a/docs/_docs/administrators-guide/config/cluster-config.adoc 
b/docs/_docs/administrators-guide/config/cluster-config.adoc
index 3e243590ad..afcd6d6b6b 100644
--- a/docs/_docs/administrators-guide/config/cluster-config.adoc
+++ b/docs/_docs/administrators-guide/config/cluster-config.adoc
@@ -24,7 +24,7 @@ Ignite 3 cluster configuration is shared across the whole 
cluster. Regardless of
     "batchSize" : 5,
     "lowWatermark" : {
       "dataAvailabilityTime" : 600000,
-      "updateFrequency" : 300000
+      "updateInterval" : 300000
     },
     "threads" : 16
   },
@@ -35,7 +35,7 @@ Ignite 3 cluster configuration is shared across the whole 
cluster. Regardless of
 |Property|Default|Description
 |batchSize|5|Garbage collection batch size.
 |lowWatermark.dataAvailabilityTime|600000|The duration outdated versions are 
available for.
-|lowWatermark.updateFrequency|300000|The frequency of low watermark updates.
+|lowWatermark.updateInterval|300000|The interval between low watermark updates.
 |threads|16|The number of threads used by garbage collector.
 |======
 
@@ -133,4 +133,4 @@ Ignite 3 cluster configuration is shared across the whole 
cluster. Regardless of
 |======
 |Property|Default|Description
 |abandonedCheckTs|5000|The amount of time after which the transaction is 
considered abandoned.
-|======
\ No newline at end of file
+|======
diff --git a/docs/_docs/administrators-guide/config/node-config.adoc 
b/docs/_docs/administrators-guide/config/node-config.adoc
index 06682e14ab..d2712c7253 100644
--- a/docs/_docs/administrators-guide/config/node-config.adoc
+++ b/docs/_docs/administrators-guide/config/node-config.adoc
@@ -78,26 +78,6 @@ See the link:/clients/overview[Clients] section for 
information on configuring c
 |======
 
 
-== Expiration Configuration
-
-[source, json]
-----
-  "expiration" : {
-    "batchSize" : 1000,
-    "checkFrequency" : 600000,
-    "parallelismLevel" : 1
-  },
-----
-
-[cols="1,1,3",opts="header", stripes=none]
-|======
-|Property|Default|Description
-|batchSize|1000|The number of items that can be expired at once.
-|checkFrequency|600000|How often the data is checked for expiration.
-|parallelismLevel|1|The number of threads used for data expiry.
-|======
-
-
 == Network Configuration
 
 [source, json]
@@ -232,9 +212,9 @@ See the link:/clients/overview[Clients] section for 
information on configuring c
     "responseTimeout" : 3000,
     "retryDelay" : 200,
     "retryTimeout" : 10000,
-    "rpcInstallSnapshotTimeout" : 300000,
+    "installSnapshotTimeout" : 300000,
     "volatileRaft" : {
-      "logStorage" : {
+      "logStorageBudget" : {
         "name" : "unlimited"
       }
     }
@@ -248,8 +228,8 @@ See the link:/clients/overview[Clients] section for 
information on configuring c
 |responseTimeout|3000|Raft group response timeout.
 |retryDelay|200|The delay before the request is retried.
 |retryTimeout|10000|The timeout after which the request is considered timed 
out.
-|rpcInstallSnapshotTimeout|300000|The maximum allowed duration from sending 
InstallSnapshot request and getting a response to it. During it, the snapshot 
must be fully transferred to a recipient and installed.
-|volatileRaft.logStorage.name||The name of the log storage used by the node.
+|installSnapshotTimeout|300000|The maximum allowed duration from sending 
InstallSnapshot request and getting a response to it. During it, the snapshot 
must be fully transferred to a recipient and installed.
+|volatileRaft.logStorageBudget.name||The name of the log storage budget used 
by the node.
 
 |======
 
@@ -336,4 +316,4 @@ See the link:/clients/overview[Clients] section for 
information on configuring c
 
 |storageProfiles||The list of available storage profiles.
 
-|======
\ No newline at end of file
+|======
diff --git a/docs/_docs/administrators-guide/config/storage/persistent.adoc 
b/docs/_docs/administrators-guide/config/storage/persistent.adoc
index 42e992fc5a..53c358cf01 100644
--- a/docs/_docs/administrators-guide/config/storage/persistent.adoc
+++ b/docs/_docs/administrators-guide/config/storage/persistent.adoc
@@ -55,8 +55,8 @@ The table below describes checkpoint configuration:
 |checkpointDelayMillis|200| Delay before staring a checkpoint after receiving 
the command.
 |checkpointThreads|4| Number of CPU threads dedicated to checkpointing.
 |compactionThreads|4| Number of CPU threads dedicated to data compaction.
-|frequency|180000|Checkpoint frequency in milliseconds.
-|frequencyDeviation|40| Allowed deviation in checkpoint frequency, in 
milliseconds.
+|interval|180000|Interval between checkpoints in milliseconds.
+|intervalDeviation|40| Allowed deviation in checkpoint interval, percent.
 |logReadLockThresholdTimeout|0| Threshold for logging long read locks, in 
milliseconds.
 |readLockTimeout|10000| Timeout for checkpoint read lock acquisition, in 
milliseconds.
 |useAsyncFileIoFactory|true| If Ignite uses asynchronous file I/O operations 
provider.
@@ -74,4 +74,4 @@ ignite config set --type cluster \
         maxSize: 256000000
     }]
 }"
-----
\ No newline at end of file
+----
diff --git 
a/docs/_docs/administrators-guide/config/storage/table-configuration.adoc 
b/docs/_docs/administrators-guide/config/storage/table-configuration.adoc
index 04d0d7f875..6a78a026b4 100644
--- a/docs/_docs/administrators-guide/config/storage/table-configuration.adoc
+++ b/docs/_docs/administrators-guide/config/storage/table-configuration.adoc
@@ -27,7 +27,7 @@ Generic configuration settings are applied to all tables and 
indexes in the clus
 |gcThreads|16| Number of CPU threads dedicated to garbage collection.
 |globalIdCounter|0|Current global ID of the table. Incremented automatically 
when a new table is created.
 |lowWatermark.dataAvailabilityTime|2700000|The duration deleted data is kept 
in database, in milliseconds.
-|lowWatermark.updateFrequency|300000| Low watermark update frequency (in 
milliseconds).
+|lowWatermark.updateInterval|300000| Low watermark update interval (in 
milliseconds).
 |===
 
 
@@ -59,4 +59,4 @@ Index configuration parameters can be used to fine tune index 
parameters manuall
 |id||Index ID.
 |name||Index name.
 |tableId||The ID of the table the index.
-|===
\ No newline at end of file
+|===
diff --git a/docs/_docs/administrators-guide/config/storage/volatile.adoc 
b/docs/_docs/administrators-guide/config/storage/volatile.adoc
index 9cb15a9a7c..4f332309de 100644
--- a/docs/_docs/administrators-guide/config/storage/volatile.adoc
+++ b/docs/_docs/administrators-guide/config/storage/volatile.adoc
@@ -30,7 +30,6 @@ When it is enabled for the data region, Ignite stores all 
data in the data regio
 |name|| The name of the data region.
 |initSize|`256 * 1024 * 1024`| Sets the initial space allocated to the data 
region.
 |maxSize|`256 * 1024 * 1024`| Sets the maximum space that can be allocated to 
the data region.
-|emptyPagesPoolSize|100| The maximum number of empty pages Ignite will try to 
keep.
 |pageSize|16384| The size of pages in the storage, in bytes.
 |===
 
@@ -47,4 +46,4 @@ ignite config set --type cluster \
         maxSize: 256000000
     }]
 }"
-----
\ No newline at end of file
+----
diff --git a/docs/_docs/developers-guide/data-streamer.adoc 
b/docs/_docs/developers-guide/data-streamer.adoc
index 4e9977bbe2..ef0ab85553 100644
--- a/docs/_docs/developers-guide/data-streamer.adoc
+++ b/docs/_docs/developers-guide/data-streamer.adoc
@@ -102,4 +102,4 @@ CompletableFuture<Void> streamerFut = 
view.streamData(publisher, options);
 ----
 --
 
-Additionally, the data streamer periodically flushes incomplete buffers to 
avoid messages being stuck for a long time (a specific buffer can fill up 
slowly or never fill completely at all, depending on the data distribution). 
This is configured with the `autoFlushFrequency` (5000ms by default) property.
+Additionally, the data streamer periodically flushes incomplete buffers to 
avoid messages being stuck for a long time (a specific buffer can fill up 
slowly or never fill completely at all, depending on the data distribution). 
This is configured with the `autoFlushInterval` (5000ms by default) property.
diff --git a/docs/_docs/general-tips.adoc b/docs/_docs/general-tips.adoc
index 2600f7a33a..491b4f216b 100644
--- a/docs/_docs/general-tips.adoc
+++ b/docs/_docs/general-tips.adoc
@@ -55,8 +55,8 @@ You can get information about the data region by using the 
`cluster config show
     "checkpointDelayMillis" : 200,
     "checkpointThreads" : 4,
     "compactionThreads" : 4,
-    "frequency" : 180000,
-    "frequencyDeviation" : 40,
+    "interval" : 180000,
+    "intervalDeviation" : 40,
     "logReadLockThresholdTimeout" : 0,
     "readLockTimeout" : 10000,
     "useAsyncFileIoFactory" : true
diff --git 
a/modules/client/src/main/java/org/apache/ignite/internal/client/table/ClientDataStreamer.java
 
b/modules/client/src/main/java/org/apache/ignite/internal/client/table/ClientDataStreamer.java
index 027f626929..85cfab4dfc 100644
--- 
a/modules/client/src/main/java/org/apache/ignite/internal/client/table/ClientDataStreamer.java
+++ 
b/modules/client/src/main/java/org/apache/ignite/internal/client/table/ClientDataStreamer.java
@@ -158,8 +158,8 @@ class ClientDataStreamer {
             }
 
             @Override
-            public int autoFlushFrequency() {
-                return options.autoFlushFrequency();
+            public int autoFlushInterval() {
+                return options.autoFlushInterval();
             }
         };
     }
diff --git 
a/modules/client/src/test/java/org/apache/ignite/client/DataStreamerTest.java 
b/modules/client/src/test/java/org/apache/ignite/client/DataStreamerTest.java
index 75a28ffc4f..2d498b8eb0 100644
--- 
a/modules/client/src/test/java/org/apache/ignite/client/DataStreamerTest.java
+++ 
b/modules/client/src/test/java/org/apache/ignite/client/DataStreamerTest.java
@@ -167,7 +167,7 @@ public class DataStreamerTest extends 
AbstractClientTableTest {
         RecordView<Tuple> view = this.defaultTable().recordView();
 
         try (var publisher = new SimplePublisher<Tuple>()) {
-            var options = 
DataStreamerOptions.builder().autoFlushFrequency(100).build();
+            var options = 
DataStreamerOptions.builder().autoFlushInterval(100).build();
             view.streamData(publisher, options);
 
             publisher.submit(tuple(1L, "foo"));
@@ -180,7 +180,7 @@ public class DataStreamerTest extends 
AbstractClientTableTest {
         RecordView<Tuple> view = this.defaultTable().recordView();
 
         try (var publisher = new SimplePublisher<Tuple>()) {
-            var options = 
DataStreamerOptions.builder().autoFlushFrequency(-1).build();
+            var options = 
DataStreamerOptions.builder().autoFlushInterval(-1).build();
             view.streamData(publisher, options);
 
             publisher.submit(tuple(1L, "foo"));
diff --git 
a/modules/client/src/test/java/org/apache/ignite/client/PartitionAwarenessTest.java
 
b/modules/client/src/test/java/org/apache/ignite/client/PartitionAwarenessTest.java
index 84a9f4daf7..a42d6a3d0f 100644
--- 
a/modules/client/src/test/java/org/apache/ignite/client/PartitionAwarenessTest.java
+++ 
b/modules/client/src/test/java/org/apache/ignite/client/PartitionAwarenessTest.java
@@ -570,7 +570,7 @@ public class PartitionAwarenessTest extends 
AbstractClientTest {
         DataStreamerOptions options = DataStreamerOptions.builder()
                 .pageSize(1)
                 .perPartitionParallelOperations(1)
-                .autoFlushFrequency(50)
+                .autoFlushInterval(50)
                 .build();
 
         CompletableFuture<Void> fut;
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerOptions.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerOptions.java
index 82a1a62d29..148471e0d0 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerOptions.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerOptions.java
@@ -36,10 +36,10 @@ public interface StreamerOptions {
     int perPartitionParallelOperations();
 
     /**
-     * Gets the auto flush frequency, in milliseconds
+     * Gets the auto flush interval, in milliseconds
      * (the period of time after which the streamer will flush the per-node 
buffer even if it is not full).
      *
-     * @return Auto flush frequency.
+     * @return Auto flush interval.
      */
-    int autoFlushFrequency();
+    int autoFlushInterval();
 }
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerSubscriber.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerSubscriber.java
index 8b76a57a04..14fe51fd7b 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerSubscriber.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/streamer/StreamerSubscriber.java
@@ -341,7 +341,7 @@ public class StreamerSubscriber<T, E, V, R, P> implements 
Subscriber<E> {
             return;
         }
 
-        int interval = options.autoFlushFrequency();
+        int interval = options.autoFlushInterval();
 
         if (interval <= 0) {
             return;
diff --git 
a/modules/core/src/main/java/org/apache/ignite/internal/util/FastTimestamps.java
 
b/modules/core/src/main/java/org/apache/ignite/internal/util/FastTimestamps.java
index c95b683971..c1c6ac0035 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/internal/util/FastTimestamps.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/internal/util/FastTimestamps.java
@@ -24,7 +24,7 @@ public class FastTimestamps {
     private static volatile long coarseCurrentTimeMillis = 
System.currentTimeMillis();
 
     /** Note: don't change this value, because it's crucial for a timestamp 
generation. */
-    private static final long UPDATE_FREQUENCY_MS = 1;
+    private static final long UPDATE_INTERVAL_MS = 1;
 
     static {
         startUpdater();
@@ -38,7 +38,7 @@ public class FastTimestamps {
                 while (true) {
                     coarseCurrentTimeMillis = System.currentTimeMillis();
                     try {
-                        Thread.sleep(UPDATE_FREQUENCY_MS);
+                        Thread.sleep(UPDATE_INTERVAL_MS);
                     } catch (InterruptedException e) {
                         break;
                     }
diff --git 
a/modules/core/src/test/java/org/apache/ignite/internal/streamer/StreamerSubscriberTest.java
 
b/modules/core/src/test/java/org/apache/ignite/internal/streamer/StreamerSubscriberTest.java
index fa79127878..7208a78459 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/internal/streamer/StreamerSubscriberTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/internal/streamer/StreamerSubscriberTest.java
@@ -86,12 +86,12 @@ class StreamerSubscriberTest extends BaseIgniteAbstractTest 
{
     private static class Options implements StreamerOptions {
         private final int batchSize;
         private final int perPartitionParallelOperations;
-        private final int autoFlushFrequency;
+        private final int autoFlushInterval;
 
-        Options(int batchSize, int perPartitionParallelOperations, int 
autoFlushFrequency) {
+        Options(int batchSize, int perPartitionParallelOperations, int 
autoFlushInterval) {
             this.batchSize = batchSize;
             this.perPartitionParallelOperations = 
perPartitionParallelOperations;
-            this.autoFlushFrequency = autoFlushFrequency;
+            this.autoFlushInterval = autoFlushInterval;
         }
 
         @Override
@@ -105,8 +105,8 @@ class StreamerSubscriberTest extends BaseIgniteAbstractTest 
{
         }
 
         @Override
-        public int autoFlushFrequency() {
-            return autoFlushFrequency;
+        public int autoFlushInterval() {
+            return autoFlushInterval;
         }
     }
 
diff --git 
a/modules/low-watermark/src/main/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImpl.java
 
b/modules/low-watermark/src/main/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImpl.java
index 6e11fa020d..6faa14384b 100644
--- 
a/modules/low-watermark/src/main/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImpl.java
+++ 
b/modules/low-watermark/src/main/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImpl.java
@@ -72,7 +72,7 @@ import org.jetbrains.annotations.Nullable;
  * <p>Low watermark updating occurs in the following cases (will only be 
updated if the new value is greater than the existing one):</p>
  * <ul>
  *     <li>By calling {@link #updateAndNotify(HybridTimestamp)}.</li>
- *     <li>In the background every {@link 
LowWatermarkConfigurationSchema#updateFrequency} milliseconds, a new value will 
be created in
+ *     <li>In the background every {@link 
LowWatermarkConfigurationSchema#updateInterval} milliseconds, a new value will 
be created in
  *     {@link #createNewLowWatermarkCandidate()}.</li>
  * </ul>
  *
@@ -214,7 +214,7 @@ public class LowWatermarkImpl extends 
AbstractEventProducer<LowWatermarkEvent, L
 
         ScheduledFuture<?> newScheduledFuture = scheduledThreadPool.schedule(
                 () -> updateLowWatermark(createNewLowWatermarkCandidate()),
-                lowWatermarkConfig.updateFrequency().value(),
+                lowWatermarkConfig.updateInterval().value(),
                 TimeUnit.MILLISECONDS
         );
 
diff --git 
a/modules/low-watermark/src/test/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImplTest.java
 
b/modules/low-watermark/src/test/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImplTest.java
index 2e4c516edb..4337a6b830 100644
--- 
a/modules/low-watermark/src/test/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImplTest.java
+++ 
b/modules/low-watermark/src/test/java/org/apache/ignite/internal/lowwatermark/LowWatermarkImplTest.java
@@ -202,14 +202,14 @@ public class LowWatermarkImplTest extends 
BaseIgniteAbstractTest {
     /** Let's make sure that the low watermark update happens one by one and 
not in parallel. */
     @Test
     void testUpdateWatermarkSequentially() throws Exception {
-        assertThat(lowWatermarkConfig.updateFrequency().update(10L), 
willSucceedFast());
+        assertThat(lowWatermarkConfig.updateInterval().update(10L), 
willSucceedFast());
 
         var onLwmChangedLatch = new CountDownLatch(3);
 
         var onLwmChangedFinishFuture = new CompletableFuture<>();
 
         try {
-            assertThat(lowWatermarkConfig.updateFrequency().update(100L), 
willSucceedFast());
+            assertThat(lowWatermarkConfig.updateInterval().update(100L), 
willSucceedFast());
 
             when(lwmChangedListener.notify(any())).then(invocation -> {
                 onLwmChangedLatch.countDown();
diff --git 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/PageMemoryCheckpointConfigurationSchema.java
 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/PageMemoryCheckpointConfigurationSchema.java
index 3356e92cd2..75c15ce594 100644
--- 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/PageMemoryCheckpointConfigurationSchema.java
+++ 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/PageMemoryCheckpointConfigurationSchema.java
@@ -26,15 +26,18 @@ import org.apache.ignite.configuration.validation.Range;
  */
 @Config
 public class PageMemoryCheckpointConfigurationSchema {
-    /** Checkpoint frequency in milliseconds. */
+    /** Interval between checkpoints in milliseconds. */
     @Range(min = 0)
     @Value(hasDefault = true)
-    public long frequency = 180_000;
+    public long interval = 180_000;
 
-    /** Checkpoint frequency deviation. */
+    /**
+     * Max deviation (in percent) of intervals between checkpoints. If this is 
20 and {@link #interval} is 1000, then the effective
+     * checkpoint interval values will be between 900 and 1100.
+     */
     @Range(min = 0, max = 100)
     @Value(hasDefault = true)
-    public int frequencyDeviation = 40;
+    public int intervalDeviation = 40;
 
     /** Delay before executing a checkpoint triggered by RAFT. */
     @Range(min = 0)
diff --git 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/VolatilePageMemoryProfileConfigurationSchema.java
 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/VolatilePageMemoryProfileConfigurationSchema.java
index 75d7a1c6cc..c485947f9e 100644
--- 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/VolatilePageMemoryProfileConfigurationSchema.java
+++ 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/configuration/schema/VolatilePageMemoryProfileConfigurationSchema.java
@@ -46,8 +46,4 @@ public class VolatilePageMemoryProfileConfigurationSchema 
extends StorageProfile
     /** Maximum memory region size in bytes. */
     @Value(hasDefault = true)
     public long maxSize = DFLT_DATA_REGION_MAX_SIZE;
-
-    /** Maximum amount of empty pages to keep in memory. */
-    @Value(hasDefault = true)
-    public int emptyPagesPoolSize = 100;
 }
diff --git 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/Checkpointer.java
 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/Checkpointer.java
index bf896227ee..a197098c4f 100644
--- 
a/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/Checkpointer.java
+++ 
b/modules/page-memory/src/main/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/Checkpointer.java
@@ -82,7 +82,7 @@ import org.jetbrains.annotations.Nullable;
  * <p>Responsiblity:
  * <ul>
  * <li>Provide the API for schedule/trigger the checkpoint.</li>
- * <li>Schedule new checkpoint after current one according to checkpoint 
frequency.</li>
+ * <li>Schedule new checkpoint after current one according to checkpoint 
interval.</li>
  * <li>Failure handling.</li>
  * <li>Managing of page write threads.</li>
  * <li>Logging and metrics of checkpoint.</li>
@@ -760,19 +760,19 @@ public class Checkpointer extends IgniteWorker {
     long nextCheckpointInterval() {
         PageMemoryCheckpointView checkpointConfigView = 
checkpointConfig.value();
 
-        long frequency = checkpointConfigView.frequency();
-        int deviation = checkpointConfigView.frequencyDeviation();
+        long interval = checkpointConfigView.interval();
+        int deviation = checkpointConfigView.intervalDeviation();
 
         if (deviation == 0) {
-            return frequency;
+            return interval;
         }
 
-        long deviationMills = frequency * deviation;
+        long deviationMillis = interval * deviation;
 
-        long startDelay = 
ThreadLocalRandom.current().nextLong(max(safeAbs(deviationMills) / 100, 1))
-                - max(safeAbs(deviationMills) / 200, 1);
+        long startDelay = 
ThreadLocalRandom.current().nextLong(max(safeAbs(deviationMillis) / 100, 1))
+                - max(safeAbs(deviationMillis) / 200, 1);
 
-        return safeAbs(frequency + startDelay);
+        return safeAbs(interval + startDelay);
     }
 
     private void fsyncDeltaFilePageStoreOnCheckpointThread(
diff --git 
a/modules/page-memory/src/test/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/CheckpointerTest.java
 
b/modules/page-memory/src/test/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/CheckpointerTest.java
index 65ff24c30f..aea50dee59 100644
--- 
a/modules/page-memory/src/test/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/CheckpointerTest.java
+++ 
b/modules/page-memory/src/test/java/org/apache/ignite/internal/pagememory/persistence/checkpoint/CheckpointerTest.java
@@ -94,7 +94,7 @@ public class CheckpointerTest extends BaseIgniteAbstractTest {
 
     private static PageIoRegistry ioRegistry;
 
-    @InjectConfiguration("mock : {checkpointThreads=1, frequency=1000, 
frequencyDeviation=0}")
+    @InjectConfiguration("mock : {checkpointThreads=1, interval=1000, 
intervalDeviation=0}")
     private PageMemoryCheckpointConfiguration checkpointConfig;
 
     @BeforeAll
@@ -248,7 +248,7 @@ public class CheckpointerTest extends 
BaseIgniteAbstractTest {
 
     @Test
     void testWaitCheckpointEvent() throws Exception {
-        checkpointConfig.frequency().update(200L).get(100, MILLISECONDS);
+        checkpointConfig.interval().update(200L).get(100, MILLISECONDS);
 
         Checkpointer checkpointer = new Checkpointer(
                 "test",
@@ -278,7 +278,7 @@ public class CheckpointerTest extends 
BaseIgniteAbstractTest {
 
     @Test
     void testCheckpointBody() throws Exception {
-        checkpointConfig.frequency().update(100L).get(100, MILLISECONDS);
+        checkpointConfig.interval().update(100L).get(100, MILLISECONDS);
 
         Checkpointer checkpointer = spy(new Checkpointer(
                 "test",
@@ -297,7 +297,7 @@ public class CheckpointerTest extends 
BaseIgniteAbstractTest {
                 .futureFor(FINISHED)
                 .whenComplete((unused, throwable) -> {
                     try {
-                        checkpointConfig.frequency().update(10_000L).get(100, 
MILLISECONDS);
+                        checkpointConfig.interval().update(10_000L).get(100, 
MILLISECONDS);
 
                         verify(checkpointer, times(1)).doCheckpoint();
 
@@ -443,24 +443,24 @@ public class CheckpointerTest extends 
BaseIgniteAbstractTest {
 
         // Checks case 0 deviation.
 
-        checkpointConfig.frequencyDeviation().update(0).get(100, MILLISECONDS);
+        checkpointConfig.intervalDeviation().update(0).get(100, MILLISECONDS);
 
-        checkpointConfig.frequency().update(1_000L).get(100, MILLISECONDS);
+        checkpointConfig.interval().update(1_000L).get(100, MILLISECONDS);
         assertEquals(1_000, checkpointer.nextCheckpointInterval());
 
-        checkpointConfig.frequency().update(2_000L).get(100, MILLISECONDS);
+        checkpointConfig.interval().update(2_000L).get(100, MILLISECONDS);
         assertEquals(2_000, checkpointer.nextCheckpointInterval());
 
         // Checks for non-zero deviation.
 
-        checkpointConfig.frequencyDeviation().update(10).get(100, 
MILLISECONDS);
+        checkpointConfig.intervalDeviation().update(10).get(100, MILLISECONDS);
 
         assertThat(
                 checkpointer.nextCheckpointInterval(),
                 allOf(greaterThanOrEqualTo(1_900L), lessThanOrEqualTo(2_100L))
         );
 
-        checkpointConfig.frequencyDeviation().update(20).get(100, 
MILLISECONDS);
+        checkpointConfig.intervalDeviation().update(20).get(100, MILLISECONDS);
 
         assertThat(
                 checkpointer.nextCheckpointInterval(),
diff --git 
a/modules/platforms/dotnet/Apache.Ignite.Tests/Table/DataStreamerTests.cs 
b/modules/platforms/dotnet/Apache.Ignite.Tests/Table/DataStreamerTests.cs
index e5b64ff070..644b55cbcb 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Tests/Table/DataStreamerTests.cs
+++ b/modules/platforms/dotnet/Apache.Ignite.Tests/Table/DataStreamerTests.cs
@@ -147,7 +147,7 @@ public class DataStreamerTests : IgniteTestsBase
     }
 
     [Test]
-    public async Task TestAutoFlushFrequency(
+    public async Task TestAutoFlushInterval(
         [Values(true, false)] bool enabled,
         [Values(true, false)] bool withReceiver)
     {
@@ -155,7 +155,7 @@ public class DataStreamerTests : IgniteTestsBase
 
         var options = new DataStreamerOptions
         {
-            AutoFlushFrequency = enabled
+            AutoFlushInterval = enabled
                 ? TimeSpan.FromMilliseconds(50)
                 : TimeSpan.MaxValue
         };
@@ -210,8 +210,8 @@ public class DataStreamerTests : IgniteTestsBase
         AssertException(DataStreamerOptions.Default with { PageSize = -10 }, 
"PageSize should be positive.");
         AssertException(DataStreamerOptions.Default with { RetryLimit = -1 }, 
"RetryLimit should be non-negative.");
         AssertException(
-            DataStreamerOptions.Default with { AutoFlushFrequency = 
TimeSpan.FromDays(-1) },
-            "AutoFlushFrequency should be positive.");
+            DataStreamerOptions.Default with { AutoFlushInterval = 
TimeSpan.FromDays(-1) },
+            "AutoFlushInterval should be positive.");
 
         void AssertException(DataStreamerOptions options, string message)
         {
diff --git 
a/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamer.cs 
b/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamer.cs
index 279943af32..6710c5bcd2 100644
--- a/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamer.cs
+++ b/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamer.cs
@@ -313,12 +313,12 @@ internal static class DataStreamer
         {
             while (!flushCt.IsCancellationRequested)
             {
-                await Task.Delay(options.AutoFlushFrequency, 
flushCt).ConfigureAwait(false);
+                await Task.Delay(options.AutoFlushInterval, 
flushCt).ConfigureAwait(false);
                 var ts = Stopwatch.GetTimestamp();
 
                 foreach (var batch in batches.Values)
                 {
-                    if (batch.Count > 0 && ts - batch.LastFlush > 
options.AutoFlushFrequency.Ticks)
+                    if (batch.Count > 0 && ts - batch.LastFlush > 
options.AutoFlushInterval.Ticks)
                     {
                         await SendAsync(batch).ConfigureAwait(false);
                     }
@@ -352,9 +352,9 @@ internal static class DataStreamer
             $"{nameof(options.PageSize)} should be positive.");
 
         IgniteArgumentCheck.Ensure(
-            options.AutoFlushFrequency > TimeSpan.Zero,
-            nameof(options.AutoFlushFrequency),
-            $"{nameof(options.AutoFlushFrequency)} should be positive.");
+            options.AutoFlushInterval > TimeSpan.Zero,
+            nameof(options.AutoFlushInterval),
+            $"{nameof(options.AutoFlushInterval)} should be positive.");
 
         IgniteArgumentCheck.Ensure(
             options.RetryLimit >= 0,
diff --git 
a/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamerWithReceiver.cs
 
b/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamerWithReceiver.cs
index ef08db55ca..a321a7df96 100644
--- 
a/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamerWithReceiver.cs
+++ 
b/modules/platforms/dotnet/Apache.Ignite/Internal/Table/DataStreamerWithReceiver.cs
@@ -287,12 +287,12 @@ internal static class DataStreamerWithReceiver
         {
             while (!flushCt.IsCancellationRequested)
             {
-                await Task.Delay(options.AutoFlushFrequency, 
flushCt).ConfigureAwait(false);
+                await Task.Delay(options.AutoFlushInterval, 
flushCt).ConfigureAwait(false);
                 var ts = Stopwatch.GetTimestamp();
 
                 foreach (var batch in batches.Values)
                 {
-                    if (batch.Count > 0 && ts - batch.LastFlush > 
options.AutoFlushFrequency.Ticks)
+                    if (batch.Count > 0 && ts - batch.LastFlush > 
options.AutoFlushInterval.Ticks)
                     {
                         await SendAsync(batch).ConfigureAwait(false);
                     }
diff --git 
a/modules/platforms/dotnet/Apache.Ignite/Table/DataStreamerOptions.cs 
b/modules/platforms/dotnet/Apache.Ignite/Table/DataStreamerOptions.cs
index 69c7fa53ad..5d662d6f3f 100644
--- a/modules/platforms/dotnet/Apache.Ignite/Table/DataStreamerOptions.cs
+++ b/modules/platforms/dotnet/Apache.Ignite/Table/DataStreamerOptions.cs
@@ -25,9 +25,9 @@ using System;
 /// <param name="PageSize">The number of entries that will be sent to the 
cluster in one network call.</param>
 /// <param name="RetryLimit">Retry limit for a batch. If a batch fails to be 
sent to the cluster,
 /// the streamer will retry it a number of times.</param>
-/// <param name="AutoFlushFrequency">Auto flush frequency - the period of time 
after which the streamer
+/// <param name="AutoFlushInterval">Auto flush interval - the period of time 
after which the streamer
 /// will flush the per-node buffer even if it is not full.</param>
-public sealed record DataStreamerOptions(int PageSize, int RetryLimit, 
TimeSpan AutoFlushFrequency)
+public sealed record DataStreamerOptions(int PageSize, int RetryLimit, 
TimeSpan AutoFlushInterval)
 {
     /// <summary>
     /// Default streamer options.
@@ -41,7 +41,7 @@ public sealed record DataStreamerOptions(int PageSize, int 
RetryLimit, TimeSpan
         : this(
             PageSize: 1000,
             RetryLimit: 16,
-            AutoFlushFrequency: TimeSpan.FromSeconds(5))
+            AutoFlushInterval: TimeSpan.FromSeconds(5))
     {
         // No-op.
     }
diff --git 
a/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/RaftConfigurationSchema.java
 
b/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/RaftConfigurationSchema.java
index 5b7191b236..da92e1d74e 100644
--- 
a/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/RaftConfigurationSchema.java
+++ 
b/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/RaftConfigurationSchema.java
@@ -29,13 +29,13 @@ import org.apache.ignite.configuration.annotation.Value;
 @ConfigurationRoot(rootName = "raft", type = ConfigurationType.LOCAL)
 public class RaftConfigurationSchema {
     /**
-     * RPC Timeout for InstallSnapshot request (in milliseconds). This is the 
maximum allowed duration from sending
+     * Timeout for InstallSnapshot request (in milliseconds). This is the 
maximum allowed duration from sending
      * InstallSnapshot request and getting a response to it; during it, the 
snapshot must be fully transferred to
      * a recipient and installed.
      */
     @Value(hasDefault = true)
     // TODO: IGNITE-18480 - is 5 minutes a good default?
-    public int rpcInstallSnapshotTimeout = 5 * 60 * 1000;
+    public int installSnapshotTimeout = 5 * 60 * 1000;
 
     /** Configuration for Raft groups corresponding to table partitions. */
     // TODO: IGNITE-16647 - Volatile RAFT configuration should be moved 
elsewhere
diff --git 
a/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/VolatileRaftConfigurationSchema.java
 
b/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/VolatileRaftConfigurationSchema.java
index e2f3e8c9a3..c0f437e86d 100644
--- 
a/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/VolatileRaftConfigurationSchema.java
+++ 
b/modules/raft-api/src/main/java/org/apache/ignite/internal/raft/configuration/VolatileRaftConfigurationSchema.java
@@ -27,5 +27,5 @@ import org.apache.ignite.configuration.annotation.ConfigValue;
 public class VolatileRaftConfigurationSchema {
     /** Config of log storage budget. */
     @ConfigValue
-    public LogStorageBudgetConfigurationSchema logStorage;
+    public LogStorageBudgetConfigurationSchema logStorageBudget;
 }
diff --git 
a/modules/raft/src/integrationTest/java/org/apache/ignite/internal/raft/ItLozaTest.java
 
b/modules/raft/src/integrationTest/java/org/apache/ignite/internal/raft/ItLozaTest.java
index 7c249f5f4f..1d9c71fe42 100644
--- 
a/modules/raft/src/integrationTest/java/org/apache/ignite/internal/raft/ItLozaTest.java
+++ 
b/modules/raft/src/integrationTest/java/org/apache/ignite/internal/raft/ItLozaTest.java
@@ -261,7 +261,7 @@ public class ItLozaTest extends IgniteAbstractTest {
             }
         };
 
-        LogStorageBudgetView volatileCfg = 
raftConfiguration.volatileRaft().logStorage().value();
+        LogStorageBudgetView volatileCfg = 
raftConfiguration.volatileRaft().logStorageBudget().value();
 
         LogStorageFactory volatileLogStorageFactory = 
volatileLogStorageFactoryCreator.factory(volatileCfg);
 
diff --git 
a/modules/raft/src/main/java/org/apache/ignite/internal/raft/Loza.java 
b/modules/raft/src/main/java/org/apache/ignite/internal/raft/Loza.java
index 614f4057a0..982cdc150d 100644
--- a/modules/raft/src/main/java/org/apache/ignite/internal/raft/Loza.java
+++ b/modules/raft/src/main/java/org/apache/ignite/internal/raft/Loza.java
@@ -169,7 +169,7 @@ public class Loza implements RaftManager {
         metricManager.enable(stripeSource);
 
         opts.setRaftMetrics(stripeSource);
-        
opts.setRpcInstallSnapshotTimeout(raftConfig.rpcInstallSnapshotTimeout());
+        opts.setRpcInstallSnapshotTimeout(raftConfig.installSnapshotTimeout());
         opts.setStripes(raftConfig.stripes());
         opts.setLogStripesCount(raftConfig.logStripesCount());
         opts.setLogYieldStrategy(raftConfig.logYieldStrategy());
diff --git 
a/modules/api/src/main/java/org/apache/ignite/table/DataStreamerOptions.java 
b/modules/api/src/main/java/org/apache/ignite/table/DataStreamerOptions.java
index 0ae7be0d01..805317853b 100644
--- a/modules/api/src/main/java/org/apache/ignite/table/DataStreamerOptions.java
+++ b/modules/api/src/main/java/org/apache/ignite/table/DataStreamerOptions.java
@@ -28,7 +28,7 @@ public class DataStreamerOptions {
 
     private final int perPartitionParallelOperations;
 
-    private final int autoFlushFrequency;
+    private final int autoFlushInterval;
 
     private final int retryLimit;
 
@@ -37,13 +37,13 @@ public class DataStreamerOptions {
      *
      * @param pageSize Page size.
      * @param perPartitionParallelOperations Per partition parallel operations.
      * @param autoFlushFrequency Auto flush frequency.
      * @param retryLimit Retry limit.
      */
-    private DataStreamerOptions(int pageSize, int 
perPartitionParallelOperations, int autoFlushFrequency, int retryLimit) {
+    private DataStreamerOptions(int pageSize, int 
perPartitionParallelOperations, int autoFlushInterval, int retryLimit) {
         this.pageSize = pageSize;
         this.perPartitionParallelOperations = perPartitionParallelOperations;
-        this.autoFlushFrequency = autoFlushFrequency;
+        this.autoFlushInterval = autoFlushInterval;
         this.retryLimit = retryLimit;
     }
 
@@ -75,13 +75,13 @@ public class DataStreamerOptions {
     }
 
     /**
      * Gets the auto flush frequency, in milliseconds
      * (the period of time after which the streamer will flush the per-node 
buffer even if it is not full).
      *
      * @return Auto flush frequency.
      */
-    public int autoFlushFrequency() {
-        return autoFlushFrequency;
+    public int autoFlushInterval() {
+        return autoFlushInterval;
     }
 
     /**
@@ -102,7 +102,7 @@ public class DataStreamerOptions {
 
         private int perPartitionParallelOperations = 1;
 
-        private int autoFlushFrequency = 5000;
+        private int autoFlushInterval = 5000;
 
         private int retryLimit = 16;
 
@@ -139,14 +139,14 @@ public class DataStreamerOptions {
         }
 
         /**
          * Sets the auto flush frequency, in milliseconds
          * (the period of time after which the streamer will flush the 
per-node buffer even if it is not full).
          *
-         * @param autoFlushFrequency Auto flush frequency, in milliseconds. 0 
or less means no auto flush.
+         * @param autoFlushInterval Auto flush interval, in milliseconds. 0 or 
less means no auto flush.
          * @return This builder instance.
          */
-        public Builder autoFlushFrequency(int autoFlushFrequency) {
-            this.autoFlushFrequency = autoFlushFrequency;
+        public Builder autoFlushInterval(int autoFlushInterval) {
+            this.autoFlushInterval = autoFlushInterval;
 
             return this;
         }
@@ -170,7 +170,7 @@ public class DataStreamerOptions {
          * @return Data streamer options.
          */
         public DataStreamerOptions build() {
-            return new DataStreamerOptions(pageSize, 
perPartitionParallelOperations, autoFlushFrequency, retryLimit);
+            return new DataStreamerOptions(pageSize, 
perPartitionParallelOperations, autoFlushInterval, retryLimit);
         }
     }
@@ -37,13 +37,13 @@ public class DataStreamerOptions {
      * @param pageSize Page size.
      * @param perPartitionParallelOperations Per partition parallel operations.
-     * @param autoFlushFrequency Auto flush frequency.
+     * @param autoFlushInterval Auto flush interval.
      * @param retryLimit Retry limit.
      */
@@ -75,13 +75,13 @@ public class DataStreamerOptions {
 
     /**
-     * Gets the auto flush frequency, in milliseconds
+     * Gets the auto flush interval, in milliseconds
      * (the period of time after which the streamer will flush the per-node 
buffer even if it is not full).
@@ -75,13 +75,13 @@ public class DataStreamerOptions {
buffer even if it is not full).
      *
-     * @return Auto flush frequency.
+     * @return Auto flush interval.
      */
@@ -139,14 +139,14 @@ public class DataStreamerOptions {
 
         /**
-         * Sets the auto flush frequency, in milliseconds
+         * Sets the auto flush interval, in milliseconds
          * (the period of time after which the streamer will flush the 
per-node buffer even if it is not full).
 }
diff --git 
a/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/ReplicaManager.java
 
b/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/ReplicaManager.java
index bf5b209673..26483f17cd 100644
--- 
a/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/ReplicaManager.java
+++ 
b/modules/replicator/src/main/java/org/apache/ignite/internal/replicator/ReplicaManager.java
@@ -775,7 +775,7 @@ public class ReplicaManager extends 
AbstractEventProducer<LocalReplicaEvent, Loc
         RaftGroupOptions raftGroupOptions;
 
         if (isVolatileStorage) {
-            LogStorageBudgetView view = ((Loza) 
raftManager).volatileRaft().logStorage().value();
+            LogStorageBudgetView view = ((Loza) 
raftManager).volatileRaft().logStorageBudget().value();
             raftGroupOptions = RaftGroupOptions.forVolatileStores()
                     
.setLogStorageFactory(volatileLogStorageFactoryCreator.factory(view))
                     .raftMetaStorageFactory((groupId, raftOptions) -> new 
VolatileRaftMetaStorage());
diff --git 
a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/inmemory/ItRaftStorageVolatilityTest.java
 
b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/inmemory/ItRaftStorageVolatilityTest.java
index 9a646eb825..0159cc1494 100644
--- 
a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/inmemory/ItRaftStorageVolatilityTest.java
+++ 
b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/inmemory/ItRaftStorageVolatilityTest.java
@@ -240,7 +240,7 @@ class ItRaftStorageVolatilityTest extends 
ClusterPerTestIntegrationTest {
         CompletableFuture<Void> configUpdateFuture = 
unwrapIgniteImpl(node(0)).nodeConfiguration().getConfiguration(RaftConfiguration.KEY)
                 .change(cfg -> {
                     cfg.changeVolatileRaft(change -> {
-                        change.changeLogStorage(
+                        change.changeLogStorageBudget(
                                 budgetChange -> 
budgetChange.convert(EntryCountBudgetChange.class).changeEntriesCountLimit(1)
                         );
                     });
diff --git 
a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/streamer/ItAbstractDataStreamerTest.java
 
b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/streamer/ItAbstractDataStreamerTest.java
index b957dae3c6..a04469b3d7 100644
--- 
a/modules/runner/src/integrationTest/java/org/apache/ignite/internal/streamer/ItAbstractDataStreamerTest.java
+++ 
b/modules/runner/src/integrationTest/java/org/apache/ignite/internal/streamer/ItAbstractDataStreamerTest.java
@@ -188,7 +188,7 @@ public abstract class ItAbstractDataStreamerTest extends 
ClusterPerClassIntegrat
         CompletableFuture<Void> streamerFut;
 
         try (var publisher = new SimplePublisher<Tuple>()) {
-            var options = 
DataStreamerOptions.builder().autoFlushFrequency(100).build();
+            var options = 
DataStreamerOptions.builder().autoFlushInterval(100).build();
             streamerFut = view.streamData(publisher, options);
 
             publisher.submit(tuple(1, "foo"));
@@ -204,7 +204,7 @@ public abstract class ItAbstractDataStreamerTest extends 
ClusterPerClassIntegrat
         CompletableFuture<Void> streamerFut;
 
         try (var publisher = new SimplePublisher<Tuple>()) {
-            var options = 
DataStreamerOptions.builder().autoFlushFrequency(-1).build();
+            var options = 
DataStreamerOptions.builder().autoFlushInterval(-1).build();
             streamerFut = view.streamData(publisher, options);
 
             publisher.submit(tuple(1, "foo"));
diff --git 
a/modules/schema/src/main/java/org/apache/ignite/internal/schema/configuration/LowWatermarkConfigurationSchema.java
 
b/modules/schema/src/main/java/org/apache/ignite/internal/schema/configuration/LowWatermarkConfigurationSchema.java
index 9a1c3fb8d4..ddda23de50 100644
--- 
a/modules/schema/src/main/java/org/apache/ignite/internal/schema/configuration/LowWatermarkConfigurationSchema.java
+++ 
b/modules/schema/src/main/java/org/apache/ignite/internal/schema/configuration/LowWatermarkConfigurationSchema.java
@@ -41,8 +41,8 @@ public class LowWatermarkConfigurationSchema {
     @Value(hasDefault = true)
     public long dataAvailabilityTime = TimeUnit.MINUTES.toMillis(10);
 
-    /** Low watermark update frequency (in milliseconds). */
+    /** Low watermark update interval (in milliseconds). */
     @Range(min = 0)
     @Value(hasDefault = true)
-    public long updateFrequency = TimeUnit.MINUTES.toMillis(5);
+    public long updateInterval = TimeUnit.MINUTES.toMillis(5);
 }
diff --git 
a/modules/sql-engine/src/integrationTest/java/org/apache/ignite/internal/sql/sqllogic/ItSqlLogicTest.java
 
b/modules/sql-engine/src/integrationTest/java/org/apache/ignite/internal/sql/sqllogic/ItSqlLogicTest.java
index de5a0c216d..d64e323e52 100644
--- 
a/modules/sql-engine/src/integrationTest/java/org/apache/ignite/internal/sql/sqllogic/ItSqlLogicTest.java
+++ 
b/modules/sql-engine/src/integrationTest/java/org/apache/ignite/internal/sql/sqllogic/ItSqlLogicTest.java
@@ -339,7 +339,7 @@ public class ItSqlLogicTest extends BaseIgniteAbstractTest {
                 .clusterName("cluster")
                 .clusterConfiguration("{"
                         + "gc.lowWatermark.dataAvailabilityTime: 1010,\n"
-                        + "gc.lowWatermark.updateFrequency: 3000,\n"
+                        + "gc.lowWatermark.updateInterval: 3000,\n"
                         + "metrics.exporters.logPush.exporterName: logPush,\n"
                         + "metrics.exporters.logPush.period: 5000\n"
                         + "}")
diff --git 
a/modules/table/src/integrationTest/java/org/apache/ignite/internal/raftsnapshot/ItTableRaftSnapshotsTest.java
 
b/modules/table/src/integrationTest/java/org/apache/ignite/internal/raftsnapshot/ItTableRaftSnapshotsTest.java
index 28639db4a3..7849f8bad4 100644
--- 
a/modules/table/src/integrationTest/java/org/apache/ignite/internal/raftsnapshot/ItTableRaftSnapshotsTest.java
+++ 
b/modules/table/src/integrationTest/java/org/apache/ignite/internal/raftsnapshot/ItTableRaftSnapshotsTest.java
@@ -121,7 +121,7 @@ class ItTableRaftSnapshotsTest extends 
BaseIgniteAbstractTest {
     /**
      * Nodes bootstrap configuration pattern.
      *
-     * <p>rpcInstallSnapshotTimeout is changed to 10 seconds so that sporadic 
snapshot installation failures still
+     * <p>installSnapshotTimeout is changed to 10 seconds so that sporadic 
snapshot installation failures still
      * allow tests pass thanks to retries.
      */
     private static final String NODE_BOOTSTRAP_CFG = "{\n"
@@ -129,7 +129,7 @@ class ItTableRaftSnapshotsTest extends 
BaseIgniteAbstractTest {
             + "    port: {},\n"
             + "    nodeFinder.netClusterNodes: [ {} ]\n"
             + "  },\n"
-            + "  raft.rpcInstallSnapshotTimeout: 10000,\n"
+            + "  raft.installSnapshotTimeout: 10000,\n"
             + "  storage.profiles: {"
             + "        " + DEFAULT_AIPERSIST_PROFILE_NAME + ".engine: 
aipersist, "
             + "        " + DEFAULT_AIMEM_PROFILE_NAME + ".engine: aimem, "
diff --git 
a/modules/table/src/integrationTest/java/org/apache/ignite/internal/threading/ItTablesApiThreadingTest.java
 
b/modules/table/src/integrationTest/java/org/apache/ignite/internal/threading/ItTablesApiThreadingTest.java
index d49e814895..1a81c374aa 100644
--- 
a/modules/table/src/integrationTest/java/org/apache/ignite/internal/threading/ItTablesApiThreadingTest.java
+++ 
b/modules/table/src/integrationTest/java/org/apache/ignite/internal/threading/ItTablesApiThreadingTest.java
@@ -17,11 +17,14 @@
 
 package org.apache.ignite.internal.threading;
 
+import static java.lang.Thread.currentThread;
 import static 
org.apache.ignite.internal.PublicApiThreadingTests.anIgniteThread;
 import static 
org.apache.ignite.internal.PublicApiThreadingTests.asyncContinuationPool;
 import static org.apache.ignite.internal.TestWrappers.unwrapTableManager;
 import static 
org.apache.ignite.internal.testframework.matchers.CompletableFutureMatcher.willBe;
 import static org.hamcrest.MatcherAssert.assertThat;
+import static org.hamcrest.Matchers.either;
+import static org.hamcrest.Matchers.is;
 
 import java.util.concurrent.CompletableFuture;
 import java.util.function.Function;
@@ -52,7 +55,7 @@ class ItTablesApiThreadingTest extends 
ClusterPerClassIntegrationTest {
     void futuresCompleteInContinuationsPool(TablesAsyncOperation operation) {
         CompletableFuture<Thread> completerFuture = 
forcingSwitchFromUserThread(
                 () -> operation.executeOn(CLUSTER.aliveNode().tables())
-                        .thenApply(unused -> Thread.currentThread())
+                        .thenApply(unused -> currentThread())
         );
 
         assertThat(completerFuture, willBe(asyncContinuationPool()));
@@ -63,10 +66,10 @@ class ItTablesApiThreadingTest extends 
ClusterPerClassIntegrationTest {
     void 
futuresFromInternalCallsAreNotResubmittedToContinuationsPool(TablesAsyncOperation
 operation) {
         CompletableFuture<Thread> completerFuture = 
forcingSwitchFromUserThread(
                 () -> operation.executeOn(igniteTablesForInternalUse())
-                        .thenApply(unused -> Thread.currentThread())
+                        .thenApply(unused -> currentThread())
         );
 
-        assertThat(completerFuture, willBe(anIgniteThread()));
+        assertThat(completerFuture, 
willBe(either(anIgniteThread()).or(is(currentThread()))));
     }
 
     private static <T> T forcingSwitchFromUserThread(Supplier<? extends T> 
action) {
diff --git 
a/modules/table/src/main/java/org/apache/ignite/internal/table/DataStreamer.java
 
b/modules/table/src/main/java/org/apache/ignite/internal/table/DataStreamer.java
index ebf680f1ab..52cc9d0da3 100644
--- 
a/modules/table/src/main/java/org/apache/ignite/internal/table/DataStreamer.java
+++ 
b/modules/table/src/main/java/org/apache/ignite/internal/table/DataStreamer.java
@@ -98,8 +98,8 @@ class DataStreamer {
             }
 
             @Override
-            public int autoFlushFrequency() {
-                return options0.autoFlushFrequency();
+            public int autoFlushInterval() {
+                return options0.autoFlushInterval();
             }
         };
     }

Reply via email to